@@ -1,20 +1,19 @@
-from twisted.web.resource import Resource
-from twisted.internet.defer import maybeDeferred
-from twisted.python.failure import Failure
+from twisted.internet.defer import maybeDeferred, Deferred
 from twisted.python import log
+from twisted.python.failure import Failure
+from twisted.web.resource import Resource
 import twisted
 
 from saratoga.tools import _verifyResponseParams, _getParams
 from saratoga import (
     BadRequestParams,
-    #BadResponseParams,
-    #AuthenticationRequired,
+    AuthenticationFailed,
+    AuthenticationRequired,
     DoesNotExist,
+    APIError,
     __gitversion__
 )
 
-
-
 import json
 
 
@@ -79,12 +78,52 @@ class SaratogaResource(Resource):
             request.write(json.dumps(response))
             request.finish()
 
+            return 1
+
+
+        def _runAPICall(extraParams, res):
+
+            api, version, processor = res
+
+            ########################
+            # Get some parameters. #
+            ########################
+
+            paramsType = processor.get("paramsType", "jsonbody")
+
+            if paramsType == "url":
+                args = request.args
+                params = {}
+                for key, data in args.iteritems():
+                    params[key] = data
+                params = _getParams(params, processor)
+            elif paramsType == "jsonbody":
+                requestContent = request.content.read()
+                if requestContent:
+                    params = json.loads(requestContent)
+                else:
+                    params = {}
+                params = _getParams(params, processor)
+
+            if "saratoga_user" in params:
+                raise BadRequestParams("Forbidden keyword.")
+
+            if extraParams:
+                params = dict(params.items() + extraParams.items())
+
+            d = maybeDeferred(func, self.api.serviceClass, request, params)
+
+            return d
+
+        def _quickfail(fail):
+
+            return _error(Failure(fail), request, None, None)
+
+
         request.setHeader("Content-Type", "application/json; charset=utf-8")
         request.setHeader("Server", "Saratoga {} on Twisted {}".format(
                 __gitversion__, twisted.__version__))
 
-        #print "Looking for {}".format(request.path)
-
         api, version, processor = self.api.endpoints[request.method].get(
             request.path, (None, None, None))
 
@@ -95,37 +134,55 @@ class SaratogaResource(Resource):
             func = getattr(versionClass, "{}_{}".format(
                 api["endpoint"], request.method)).im_func
 
-            ########################
-            # Get some parameters. #
-            ########################
+            d = Deferred()
 
-            paramsType = processor.get("paramsType", "jsonbody")
+            #############################
+            # Check for authentication. #
+            #############################
 
-            try:
-                if paramsType == "url":
-                    args = request.args
-                    params = {}
-                    for key, data in args.iteritems():
-                        params[key] = data
-                    params = _getParams(params, processor)
-                elif paramsType == "jsonbody":
-                    requestContent = request.content.read()
-                    if requestContent:
-                        params = json.loads(requestContent)
-                    else:
-                        params = {}
-                    params = _getParams(params, processor)
-            except Exception, e:
-                _error(Failure(e), request, api, processor)
-                return 1
+            reqAuth = api.get("requiresAuthentication", False)
 
-            d = maybeDeferred(func, self.api.serviceClass, request, params)
+            if reqAuth:
+
+                if not hasattr(self.api.serviceClass, "auth"):
+                    fail = APIError("Authentication required, but there is not"
+                        " an available authenticator.")
+                    return _quickfail(fail)
+
+                def _authAdditional(canonicalUsername):
+
+                    return {"saratoga_user": canonicalUsername}
+
+                auth = request.getHeader("Authorization")
+
+                if not auth:
+                    fail = AuthenticationRequired("Authentication required.")
+                    return _quickfail(fail)
+
+                
+                authType, authDetails = auth.split()
+                
+                if authType.lower() == "basic":
+                    d.addCallback(lambda _:
+                        self.api.serviceClass.auth.auth_usernameAndPassword(
+                            request.getUser(), request.getPassword()))
+
+                else:
+                    fail = AuthenticationFailed(
+                        "Unsupported Authorization type '{}'".format(authType))
+                    return _quickfail(fail)
+
+                d.addCallback(_authAdditional)
+
+            d.addCallback(_runAPICall, (api, version, processor))
             d.addCallback(_write, request, api, processor)
             d.addErrback(_error, request, api, processor)
 
+            d.callback(False)
+
         else:
             fail = DoesNotExist("Endpoint does not exist.")
-            _error(Failure(fail), request, None, None)
+            _quickfail(fail)
 
         return 1
 
